@@ -19,34 +19,36 @@ logger = logging.getLogger('python_copilot_docs_hook')
 def get_copilot_suggestion(code: str) -> str:
     """Get documentation suggestion using GitHub Copilot CLI."""
     try:
-        # Try interactive suggestion
+        # Try with 'suggest' command first
         result = subprocess.run(
             ['gh', 'copilot', 'suggest'],
-            input=f"Write a Python docstring for:\n{code}",
-            capture_output=True,
+            input=f"Write a Python docstring for this code:\n{code}",
             text=True,
-            check=False
+            capture_output=True,
+            timeout=10
         )
         
         if result.returncode == 0 and result.stdout:
             return format_suggestion(result.stdout)
 
         logger.debug(f"Suggest command failed: {result.stderr}")
-        
-        # Try explain command
+
+        # Try with 'explain' command as fallback
         result = subprocess.run(
             ['gh', 'copilot', 'explain'],
             input=code,
-            capture_output=True,
             text=True,
-            check=False
+            capture_output=True,
+            timeout=10
         )
-
+        
         if result.returncode == 0 and result.stdout:
             return format_suggestion(result.stdout)
 
         logger.debug(f"Explain command failed: {result.stderr}")
 
+    except subprocess.TimeoutExpired:
+        logger.error("Copilot command timed out")
     except Exception as e:
         logger.error(f"Error getting Copilot suggestion: {e}")
 
